@@ -1,7 +1,7 @@
-function _aws_cdk_aws_iotevents_actions_SetVariableAction(p) {
-}
 function _aws_cdk_aws_iotevents_actions_LambdaInvokeAction(p) {
 }
+function _aws_cdk_aws_iotevents_actions_SetVariableAction(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -17,5 +17,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_iotevents_actions_SetVariableAction, _aws_cdk_aws_iotevents_actions_LambdaInvokeAction };
+module.exports = { print, _aws_cdk_aws_iotevents_actions_LambdaInvokeAction, _aws_cdk_aws_iotevents_actions_SetVariableAction };
 module.exports.DeprecationError = DeprecationError;
